/****************************************************************************
** Meta object code from reading C++ file 'gamescene.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/klickety-17.08.3/gamescene.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gamescene.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_GameScene_t {
    QByteArrayData data[25];
    char stringdata0[284];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_GameScene_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_GameScene_t qt_meta_stringdata_GameScene = {
    {
QT_MOC_LITERAL(0, 0, 9), // "GameScene"
QT_MOC_LITERAL(1, 10, 14), // "canUndoChanged"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 7), // "canUndo"
QT_MOC_LITERAL(4, 34, 14), // "canRedoChanged"
QT_MOC_LITERAL(5, 49, 7), // "canRedo"
QT_MOC_LITERAL(6, 57, 18), // "markedCountChanged"
QT_MOC_LITERAL(7, 76, 11), // "markedCount"
QT_MOC_LITERAL(8, 88, 18), // "remainCountChanged"
QT_MOC_LITERAL(9, 107, 11), // "remainCount"
QT_MOC_LITERAL(10, 119, 12), // "gameFinished"
QT_MOC_LITERAL(11, 132, 8), // "undoMove"
QT_MOC_LITERAL(12, 141, 8), // "redoMove"
QT_MOC_LITERAL(13, 150, 11), // "undoAllMove"
QT_MOC_LITERAL(14, 162, 11), // "redoAllMove"
QT_MOC_LITERAL(15, 174, 17), // "checkGameFinished"
QT_MOC_LITERAL(16, 192, 15), // "highlightPieces"
QT_MOC_LITERAL(17, 208, 1), // "x"
QT_MOC_LITERAL(18, 210, 1), // "y"
QT_MOC_LITERAL(19, 212, 17), // "unhighlightPieces"
QT_MOC_LITERAL(20, 230, 12), // "removePieces"
QT_MOC_LITERAL(21, 243, 6), // "resize"
QT_MOC_LITERAL(22, 250, 4), // "size"
QT_MOC_LITERAL(23, 255, 11), // "updateScene"
QT_MOC_LITERAL(24, 267, 16) // "updateBoundLines"

    },
    "GameScene\0canUndoChanged\0\0canUndo\0"
    "canRedoChanged\0canRedo\0markedCountChanged\0"
    "markedCount\0remainCountChanged\0"
    "remainCount\0gameFinished\0undoMove\0"
    "redoMove\0undoAllMove\0redoAllMove\0"
    "checkGameFinished\0highlightPieces\0x\0"
    "y\0unhighlightPieces\0removePieces\0"
    "resize\0size\0updateScene\0updateBoundLines"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_GameScene[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   94,    2, 0x06 /* Public */,
       4,    1,   97,    2, 0x06 /* Public */,
       6,    1,  100,    2, 0x06 /* Public */,
       8,    1,  103,    2, 0x06 /* Public */,
      10,    1,  106,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    0,  109,    2, 0x0a /* Public */,
      12,    0,  110,    2, 0x0a /* Public */,
      13,    0,  111,    2, 0x0a /* Public */,
      14,    0,  112,    2, 0x0a /* Public */,
      15,    0,  113,    2, 0x08 /* Private */,
      16,    2,  114,    2, 0x08 /* Private */,
      19,    2,  119,    2, 0x08 /* Private */,
      20,    2,  124,    2, 0x08 /* Private */,
      21,    1,  129,    2, 0x08 /* Private */,
      23,    0,  132,    2, 0x08 /* Private */,
      24,    0,  133,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Int,    9,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   17,   18,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   17,   18,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   17,   18,
    QMetaType::Void, QMetaType::QRectF,   22,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void GameScene::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GameScene *_t = static_cast<GameScene *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->canUndoChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->canRedoChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->markedCountChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->remainCountChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->gameFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->undoMove(); break;
        case 6: _t->redoMove(); break;
        case 7: _t->undoAllMove(); break;
        case 8: _t->redoAllMove(); break;
        case 9: _t->checkGameFinished(); break;
        case 10: _t->highlightPieces((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 11: _t->unhighlightPieces((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 12: _t->removePieces((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 13: _t->resize((*reinterpret_cast< const QRectF(*)>(_a[1]))); break;
        case 14: _t->updateScene(); break;
        case 15: _t->updateBoundLines(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (GameScene::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameScene::canUndoChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (GameScene::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameScene::canRedoChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (GameScene::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameScene::markedCountChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (GameScene::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameScene::remainCountChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (GameScene::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameScene::gameFinished)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject GameScene::staticMetaObject = {
    { &QGraphicsScene::staticMetaObject, qt_meta_stringdata_GameScene.data,
      qt_meta_data_GameScene,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *GameScene::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GameScene::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_GameScene.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsScene::qt_metacast(_clname);
}

int GameScene::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsScene::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void GameScene::canUndoChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void GameScene::canRedoChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void GameScene::markedCountChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void GameScene::remainCountChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void GameScene::gameFinished(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
