#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'customgameconfig.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUSTOMGAMECONFIG_H
#define UI_CUSTOMGAMECONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CustomGameConfig
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QSpinBox *kcfg_CustomWidth;
    QLabel *label_2;
    QSpinBox *kcfg_CustomHeight;
    QLabel *label_3;
    QSpinBox *kcfg_CustomColorCount;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *CustomGameConfig)
    {
        if (CustomGameConfig->objectName().isEmpty())
            CustomGameConfig->setObjectName(QStringLiteral("CustomGameConfig"));
        CustomGameConfig->resize(316, 241);
        gridLayout = new QGridLayout(CustomGameConfig);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        label = new QLabel(CustomGameConfig);
        label->setObjectName(QStringLiteral("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        kcfg_CustomWidth = new QSpinBox(CustomGameConfig);
        kcfg_CustomWidth->setObjectName(QStringLiteral("kcfg_CustomWidth"));
        kcfg_CustomWidth->setMinimum(2);
        kcfg_CustomWidth->setMaximum(64);

        gridLayout->addWidget(kcfg_CustomWidth, 0, 1, 1, 1);

        label_2 = new QLabel(CustomGameConfig);
        label_2->setObjectName(QStringLiteral("label_2"));

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        kcfg_CustomHeight = new QSpinBox(CustomGameConfig);
        kcfg_CustomHeight->setObjectName(QStringLiteral("kcfg_CustomHeight"));
        kcfg_CustomHeight->setMinimum(2);
        kcfg_CustomHeight->setMaximum(64);

        gridLayout->addWidget(kcfg_CustomHeight, 1, 1, 1, 1);

        label_3 = new QLabel(CustomGameConfig);
        label_3->setObjectName(QStringLiteral("label_3"));

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        kcfg_CustomColorCount = new QSpinBox(CustomGameConfig);
        kcfg_CustomColorCount->setObjectName(QStringLiteral("kcfg_CustomColorCount"));
        kcfg_CustomColorCount->setMinimum(2);
        kcfg_CustomColorCount->setMaximum(6);

        gridLayout->addWidget(kcfg_CustomColorCount, 2, 1, 1, 1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 0, 2, 1, 1);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacerItem1, 3, 1, 1, 1);


        retranslateUi(CustomGameConfig);

        QMetaObject::connectSlotsByName(CustomGameConfig);
    } // setupUi

    void retranslateUi(QWidget *CustomGameConfig)
    {
        label->setText(tr2i18n("Width:", Q_NULLPTR));
        label_2->setText(tr2i18n("Height:", Q_NULLPTR));
        label_3->setText(tr2i18n("Color count:", Q_NULLPTR));
        Q_UNUSED(CustomGameConfig);
    } // retranslateUi

};

namespace Ui {
    class CustomGameConfig: public Ui_CustomGameConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CUSTOMGAMECONFIG_H

