/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/klickety-17.08.3/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MainWindow_t {
    QByteArrayData data[23];
    char stringdata0[260];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MainWindow_t qt_meta_stringdata_MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 10), // "MainWindow"
QT_MOC_LITERAL(1, 11, 17), // "configureSettings"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 12), // "loadSettings"
QT_MOC_LITERAL(4, 43, 7), // "newGame"
QT_MOC_LITERAL(5, 51, 6), // "gameId"
QT_MOC_LITERAL(6, 58, 10), // "newNumGame"
QT_MOC_LITERAL(7, 69, 9), // "pauseGame"
QT_MOC_LITERAL(8, 79, 8), // "isPaused"
QT_MOC_LITERAL(9, 88, 11), // "restartGame"
QT_MOC_LITERAL(10, 100, 8), // "loadGame"
QT_MOC_LITERAL(11, 109, 8), // "saveGame"
QT_MOC_LITERAL(12, 118, 17), // "changeMarkedCount"
QT_MOC_LITERAL(13, 136, 11), // "markedCount"
QT_MOC_LITERAL(14, 148, 11), // "changeScore"
QT_MOC_LITERAL(15, 160, 11), // "remainCount"
QT_MOC_LITERAL(16, 172, 17), // "changeRemainCount"
QT_MOC_LITERAL(17, 190, 10), // "changeTime"
QT_MOC_LITERAL(18, 201, 7), // "newTime"
QT_MOC_LITERAL(19, 209, 14), // "showHighscores"
QT_MOC_LITERAL(20, 224, 10), // "onGameOver"
QT_MOC_LITERAL(21, 235, 16), // "setSoundsEnabled"
QT_MOC_LITERAL(22, 252, 7) // "enabled"

    },
    "MainWindow\0configureSettings\0\0"
    "loadSettings\0newGame\0gameId\0newNumGame\0"
    "pauseGame\0isPaused\0restartGame\0loadGame\0"
    "saveGame\0changeMarkedCount\0markedCount\0"
    "changeScore\0remainCount\0changeRemainCount\0"
    "changeTime\0newTime\0showHighscores\0"
    "onGameOver\0setSoundsEnabled\0enabled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   94,    2, 0x08 /* Private */,
       3,    0,   95,    2, 0x08 /* Private */,
       4,    1,   96,    2, 0x08 /* Private */,
       4,    0,   99,    2, 0x28 /* Private | MethodCloned */,
       6,    0,  100,    2, 0x08 /* Private */,
       7,    1,  101,    2, 0x08 /* Private */,
       9,    0,  104,    2, 0x08 /* Private */,
      10,    0,  105,    2, 0x08 /* Private */,
      11,    0,  106,    2, 0x08 /* Private */,
      12,    1,  107,    2, 0x08 /* Private */,
      14,    1,  110,    2, 0x08 /* Private */,
      16,    1,  113,    2, 0x08 /* Private */,
      17,    1,  116,    2, 0x08 /* Private */,
      19,    0,  119,    2, 0x08 /* Private */,
      20,    1,  120,    2, 0x08 /* Private */,
      21,    1,  123,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::QString,   18,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Bool,   22,

       0        // eod
};

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MainWindow *_t = static_cast<MainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->configureSettings(); break;
        case 1: _t->loadSettings(); break;
        case 2: _t->newGame((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->newGame(); break;
        case 4: _t->newNumGame(); break;
        case 5: _t->pauseGame((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->restartGame(); break;
        case 7: _t->loadGame(); break;
        case 8: _t->saveGame(); break;
        case 9: _t->changeMarkedCount((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->changeScore((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->changeRemainCount((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->changeTime((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->showHighscores(); break;
        case 14: _t->onGameOver((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->setSoundsEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject MainWindow::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_MainWindow.data,
      qt_meta_data_MainWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MainWindow.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
